@@ -12,7 +12,7 @@ use Cwd;
 use IO::Dir;
 use File::Spec::Functions qw(abs2rel rel2abs splitdir catfile);
 
-our $VERSION = "1.15";
+our $VERSION = "1.16";
 
 #----------------------------------------------------------------------
 # Read the default parameter values
@@ -145,17 +145,23 @@ sub get_dimensions {
 
     for my $field (qw(thumb photo)) {
         my ($width, $height) = $self->new_size($field, $old_width, $old_height);
-        $data->{"${field}_width"} = $width;
-        $data->{"${field}_height"} = $height;
+        if ($width && $height) {
+            $data->{"${field}_width"} = $width;
+            $data->{"${field}_height"} = $height;
 
-        my $sub = "build_${field}_name";
-        my $photoname = $self->$sub($filename);
-        next unless $self->is_newer($photoname, $gallery_name);
+            my $sub = "build_${field}_name";
+            my $photoname = $self->$sub($filename);
+            next unless $self->is_newer($photoname, $gallery_name);
 
-        my $photo = $self->resize_a_photo($old_photo, $width, $height,
-                                          $old_width, $old_height);
+            my $photo = $self->resize_a_photo($old_photo, $width, $height,
+                                              $old_width, $old_height);
 
-        $self->write_photo($photoname, $photo);
+            $self->write_photo($photoname, $photo);
+
+        } else {
+            $data->{"${field}_width"} = $old_width;
+            $data->{"${field}_height"} = $old_height;
+        }
     }
 
     return $data;
@@ -204,7 +210,7 @@ sub new_size {
         $factor = $self->{$height_field} / $old_height;
 
     } else {
-        die "$width_field and $height_field not set";
+        $factor = 0.0;
     }
 
     my $height = int($factor * $old_height);
@@ -380,7 +386,8 @@ proportional to the height.
 =item thumb_height
 
 The height of the thumb photos. Leave at 0 if the height is defined to be
-proportional to the width.
+proportional to the width. If both thumb_width and thumb_height are 0, no
+thumb photo will be created.
 
 =item photo_width
 
@@ -390,7 +397,8 @@ proportional to the height.
 =item photo_height
 
 The height of the photo after resizing. Leave at 0 if the height is defined to
-be proportional to the width.
+be proportional to the width. If both photo_width and photo_height are zero,
+the image will not be resized.
 
 =back
 
